@@ -2,13 +2,20 @@ use strict;
 use warnings;
 package Office365::EWS::Client::Role::SOAP;
 use Moose::Role;
+use Carp;
 with 'EWS::Client::Role::SOAP';
 sub _build_wsdl {
     my $self = shift;
     XML::Compile->addSchemaDirs( $self->schema_path );
-    my $wsdl = XML::Compile::WSDL11->new('ews-services.wsdl');
-    $wsdl->importDefinitions('ews-types.xsd');
-    $wsdl->importDefinitions('ews-messages.xsd');
+    my $wsdl = eval {
+        my $wsdl = XML::Compile::WSDL11->new($self->server_version.'-ews-services.wsdl');
+        $wsdl->importDefinitions($self->server_version.'-ews-types.xsd');
+        $wsdl->importDefinitions($self->server_version.'-ews-messages.xsd');
+        return $wsdl;
+    };
+    if ( $@ ) {
+        croak "$@ Unable to process WSDL. Are you specifying a 'server_version' that has a WSDL bundled (look in 'share' directory) with Office365::EWS::Client?\n";
+    }
     return $wsdl;
 }
 sub _build_schema_path {
@@ -36,7 +43,7 @@ Office365::EWS::Client::Role::SOAP
 
 =head1 VERSION
 
-version 1.140390
+version 1.142410
 
 =head1 AUTHOR
 
